---
title: NHN KCP 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: KCP 채널설정방법
  description: >-
    KCP 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 카드사 심사요청 등 계약 참고사항을 꼭
    확인하세요. 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
  keywords:
    - KCP
    - 일반결제
    - 정기결제
    - 결제연동
    - 채널설정방법
    - 채널추가
tags:
  - NHN KCP
  - 결제
  - 채널설정방법
pgCompanies:
  - NHN KCP
searchTags:
  - 본인인증
  - 휴대폰 본인인증
  - KCP
  - NHN KCP
  - KCP 테스트연동
  - KCP 테스트모드
  - KCP 실연동
  - KCP 실모드
  - KCP 일반결제
  - KCP 정기결제
  - KCP 결제실패
  - 테스트연동
  - 테스트결제
  - 실연동
  - 채널추가
  - 결제연동
  - KCP API
datetime: 2025-03-03T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Highlight url="#7_결제창-정기결제" text="KCP 결제창 정기결제 설정 바로가기↓" />

<Highlight url="#14_휴대폰-본인인증" text="KCP 휴대폰 본인인증 설정 바로가기↓" />

<Callout content="[연동방식]
- 결제창 : 결제대행사(PG사)의 결제창을 띄워서 그 안에서 결제수단 선택 후 결제하는 방식
- API : 직접 구현한 UI를 통해 결제 수단 정보를 입력받아 API를 통해 결제하는 방식

[모듈버전]
- V1 : 포트원 결제모듈 V1. 다양한 결제대행사와 수단을 지원
- V2 : 포트원 차세대 결제 모듈로 직관적인 인터페이스를 지원
- 신모듈 : 결제대행사의 최신 버전의 모듈
- 구모듈 : 결제대행사의 구 버전의 모듈

[결제방식]
- 일반결제 : 구매자의 결제정보를 저장하지 않는 일회성 결제 (단건결제)
- 정기결제 : 구매자의 결제정보를 저장해놓고 재결제하는 결제 (정기 / 비 정기결제)

[휴대폰본인인증] 
- NHN KCP 정책상 본인인증 테스트 연동정보가 제공되지 않습니다. 계약 후 실제 상점아이디로 테스트 하실 수 있습니다. " title="참고사항" icon="💡" />

## <Highlight text="결제창 일반/수기결제 및 API 수기/정기결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. NHN KCP 테스트 모드의 경우 결제시 실제 출금이 이루어지지 않습니다.
2. NHN KCP의 허브형인 카카오페이, 네이버페이는 테스트 모드를 지원하지 않습니다.
(NHN KCP와 계약 후 서비스 이용가능)
3. 카드사 심사 완료 후에는 NHN KCP에서 발급받은 실상점 정보로 설정 해야 합니다." icon="💡" title="참고사항" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : NHN KCP
  - 결제모듈 :  결제창 일반/수기결제 ㅣ API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (사이트코드) 클릭
  - KCP 결제창 일반결제 : **AO09C** 선택
  - KCP API 정기결제 : **A52LD** 선택
  - KCP 결제창 일반결제 (페이코 허브형) :  **AO0Q9** 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

<Callout content="1. 발급된 상점아이디의 **카드사 심사가 완료**되지 않았을 경우 결제가 실패 되오니 꼭! 확인 해주셔야 합니다.
2. NHN KCP는 간편결제별로 사이트코드가 별도로 발급 되므로 채널을 여러 개 생성해 주셔야 합니다.
3. 여러 개의 상점아이디를 설정한 경우 결제창 호출(IMP.request_pay) 시 pg파라미터로 상점아이디를 구분할 수 있습니다. 
- pg: {pg 정의 값}.{상점 아이디}" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : NHN KCP
  - 결제모듈 :  결제창 일반/수기결제 ㅣ API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (사이트코드) 클릭 : NHN KCP에서 계약완료 후 메일로 안내드립니다.
- **배치결제그룹아이디 :  KCP 정기결제인 경우에만 설정하는 아이디이며, 정기결제 이용시 필수등록 항목입니다.**
  - 확인 방법 : 해당 아이디 확인을 위해서는 KCP에서 정기결제용으로 발급받은 사이트 코드로 KCP 상점관리 페이지 접속하여 희망하는 사용자명을 입력하고 패스워드를 등록하여 사설 인증서를 발급받습니다.
  - 인증서 발급 경로 : [KCP 상점 관리자페이지↗](https://partner.kcp.co.kr/) > 접속 > 고객센터 > 인증센터 > 관리용 사설인증서 \
    \> 인증서 발급 버튼 클릭
  - 그룹 등록 경로 : [KCP 상점 관리자페이지↗](https://partner.kcp.co.kr/) > 결제관리 > 자동결제 > 그룹관리 > 그룹등록
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.
-

<Callout title="V2 NHN KCP 개발가이드 보러가기↗" />

<Callout title="V1 NHN KCP 개발가이드 보러가기↗" />

## <Highlight text="결제창 정기결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. NHN KCP 테스트 모드의 경우 결제시 실제 출금이 이루어지지 않습니다.
2. 카드사 심사 완료 후에는 NHN KCP에서 발급받은 실상점 정보로 설정 해야 합니다." icon="💡" title="참고사항" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : NHN KCP
  - 결제모듈 :  KCP 결제창 정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (사이트코드) 클릭
  - KCP 결제창 정기결제 : **A52LD** 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

<Callout content="1. 발급된 상점아이디의 **카드사 심사가 완료**되지 않았을 경우 결제가 실패 되오니 꼭! 확인 해주셔야 합니다.
2. 여러 개의 상점아이디를 설정한 경우 결제창 호출(IMP.request_pay) 시 pg파라미터로 상점아이디를 구분할 수 있습니다.
**※pg : {pg 정의 값}.{상점 아이디}**" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 :  실 연동
  - 결제대행사 : NHN KCP
  - 결제모듈 :  KCP 결제창 정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디(사이트코드) : NHN KCP에서 계약완료 후 메일로 안내드립니다.
- 배치결제그룹아이디 :  KCP 정기결제인 경우에만 설정하는 아이디이며, 정기결제 이용시 필수등록 항목입니다.
  - 확인 방법 : 해당 아이디 확인을 위해서는 KCP에서 정기결제용으로 발급받은 사이트 코드로 KCP 상점관리 페이지 접속하여 희망하는 사용자명을 입력하고 패스워드를 등록하여 사설 인증서를 발급받습니다.
  - 인증서 발급 경로 : [KCP 상점 관리자페이지↗](https://partner.kcp.co.kr/) > 접속 > 고객센터 > 인증센터 > 관리용 사설인증서 \
    \> 인증서 발급 버튼 클릭
  - 그룹 등록 경로 : [KCP 상점 관리자페이지↗](https://partner.kcp.co.kr/) > 결제관리 > 자동결제 > 그룹관리 > 그룹등록
- 과세설정 : [포트원 결제사정산 서비스↗](https://admin.portone.io/reconciliation/summary) 이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

## <Highlight text="휴대폰 본인인증" />

<Callout title="참고사항" content="1. **NHN KCP 정책상 본인인증 테스트 연동정보가 제공되지 않습니다.** 
2. 계약 후 실제 상점아이디로 테스트 하실 수 있습니다." icon="💡 " />

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(통신사 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : NHN KCP
  - 결제모듈 :  휴대폰 본인인증

#### **설정방법**

- 채널 속성 : 본인인증
- PG상점아이디 (사이트코드) : PG상점아이디(사이트코드) : NHN KCP에서 계약완료 후 메일로 안내드립니다.
- 인증서 발급 경로 : [KCP 상점 관리자페이지↗](https://partner.kcp.co.kr/) > 접속 > 고객센터 > 인증센터 > 관리용 사설인증서 > 인증서 발급 버튼 클릭
- 인증키 설정 경로 : [KCP 상점관리자페이지↗](https://partner.kcp.co.kr "KCP 상점관리자페이지↗")> 기술관리센터 > 인증센터 > 가맹점 인증키관리
  -  [KCP 상점관리자페이지↗](https://partner.kcp.co.kr "KCP 상점관리자페이지↗") 에서 직접 암복호화키를 발급해 주셔야 하며, 암호화키 미발급 시 서비스 이용이 불가합니다.
  - 통신 3사(SKT, KT, LG U+) 인증이 정상적으로 진행되는지 직접 인증 테스트 진행해 주시고, 인증이 안될 경우 NHN KCP 휴대폰본인인증 센터 ☎1666-6410(내선번호 1번)로 유선연락 바랍니다.

<Accordion title="▶KCP 관리자페이지>인증키 설정경로 이미지 참고" image="https://help.portone.io/uploads/KCP_본인인증 인증서222.png" />

- 인증결과 URL 설정 경로
  - [KCP 상점관리자페이지↗](https://partner.kcp.co.kr "KCP 상점관리자페이지↗") > 부가서비스 > 휴대폰본인확인 > 인증결과 URL 설정
    - 서비스 신청 시 기재하신 URL 주소는 기본으로 등록됩니다. 테스트하는 URL이 따로 있으신 경우 해당 URL을 함께 등록해 주세요.
    - 모바일 버전 도메인 혹은 www 포함 유무에 따라 필요시 도메인 추가해주세요. \
      (ex. '[kcp.co.kr](http://kcp.co.kr/)' 등록시, '[m.kcp.co.kr](http://m.kcp.co.kr/)' 혹은 '[www.kcp.co.kr](http://www.kcp.co.kr/)'은 별개의 도메인이므로 필요시 URL 추가 등록)
    - 인증창 호출 시 업체 측에서 전달하는 Ret\_URL(본인확인 인증 결과 리턴 페이지 설정)이 해당 메뉴에 등록되어 있지 않으면 서비스 이용이 불가합니다.

* 인증결과를 받을 URL을 설정 방법
  - 인증결과 경로 등록 URL :  <https://channel-service.prod.iamport.co/>

<Accordion title="▶KCP 관리자페이지>URL설정 경로 이미지 참고" image="https://help.portone.io/uploads/KCP_본인인증3333.png" />

- 과세설정 : [포트원 결제사정산 서비스↗](https://admin.portone.io/reconciliation/summary) 이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="V2 NHN KCP 개발가이드 보러가기↗" />

<Callout title="V1 NHN KCP 개발가이드 보러가기↗" />
